# The Core Zelos Team

* [Kevin Valakuzhy](//www.linkedin.com/in/kevin-valakuzhy-319a5447/) - Research Engineer, Developer
* [Ryan C. Court](//www.linkedin.com/in/rccourt) - Research Engineer, Developer
* [Kevin Z. Snow](//www.linkedin.com/in/kevinsnow/) - Co-Founder, Developer

### Special Thanks To

* Fabian Monrose - Co-Founder
* Ann Cox - DHS Program Manager
* Angelos Keromytis - DARPA Program Manager (Former)
* Dustin Fraze - DARPA Program Manager
* Suyup Kim - Intern
